@@ -2,7 +2,7 @@ import requests
 from bs4 import BeautifulSoup
 from fake_useragent import UserAgent
 
-import req_tools
+from req_tools import *
 from selm_tools import SelenuimTools
 from crsmysql import MySqlTools
 
@@ -24,7 +24,7 @@ class SpiderTools(object):
 
     def get_url(self,url,dynamic=False,wait_time=1,wait_show='',ssl_error=False):
         if not dynamic:
-            return req_tools.get_html(url,ssl_error=ssl_error)
+            return get_html(url,ssl_error=ssl_error)
         else:
             return self.selm.get_html(url,wait_time=wait_time,wait_show=wait_show)
 
